#
# spec file for package libv3270
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2008 Banco do Brasil S.A.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libv3270
Version:        5.3
Release:        bp154.1.392
Summary:        3270 Virtual Terminal for GTK
License:        LGPL-3.0-only
Group:          Development/Languages/C and C++
URL:            https://github.com/PerryWerneck/libv3270
Source:         libv3270-%{version}.tar.xz
BuildRequires:  autoconf >= 2.61
BuildRequires:  automake
BuildRequires:  binutils
BuildRequires:  coreutils
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  m4
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(lib3270) >= %{version}
%if 0%{?centos_version}
# CENTOS Genmarshal doesn't depend on python!
BuildRequires:  python
%endif

%description

Originally designed as part of the pw3270 application, this library
provides a TN3270 virtual terminal widget for GTK 3.

For more details, see https://softwarepublico.gov.br/social/pw3270/ .

%define MAJOR_VERSION %(echo %{version} | cut -d. -f1)
%define MINOR_VERSION %(echo %{version} | cut -d. -f2)
%define _libvrs %{MAJOR_VERSION}_%{MINOR_VERSION}
%define _product %(pkg-config --variable=product_name lib3270)

%package -n %{name}-%{_libvrs}
Summary:        TN3270 access library
Group:          Development/Languages/C and C++

%description -n %{name}-%{_libvrs}
Originally designed as part of the pw3270 application, this library
provides a TN3270 virtual terminal widget for GTK 3.

For more details, see https://softwarepublico.gov.br/social/pw3270/ .

%package devel
Summary:        Header files for the 3270 Virtual Terminal library
Group:          Development/Languages/C and C++
Requires:       %{name}-%{_libvrs} = %{version}

%description devel
Originally designed as part of the pw3270 application, this package provides the development files required to %{name}.

%package -n glade-catalog-v3270
Summary:        Glade catalog for the TN3270 terminal emulator library
Group:          Development/Languages/C and C++
Requires:       glade

%description -n glade-catalog-v3270
This package provides a catalog for Glade to allow the use of V3270
widgets in Glade.

%prep
%setup -q
NOCONFIGURE=1 ./autogen.sh
%configure --with-release=%{release}

%build
make all %{?_smp_mflags}

%install
%make_install
%find_lang %{name} langfiles

%files -n %{name}-%{_libvrs} -f langfiles
%license LICENSE
%doc AUTHORS README.md
%{_libdir}/%{name}.so.*
%{_datadir}/%{_product}/colors.conf
%dir %{_datadir}/%{_product}/remap/
%{_datadir}/%{_product}/remap/*.xml

%files devel
%{_datadir}/pw3270/pot/*.pot
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/v3270.h
%{_includedir}/v3270

%files -n glade-catalog-v3270
%{_datadir}/glade/

%post -n %{name}-%{_libvrs} -p /sbin/ldconfig
%postun -n %{name}-%{_libvrs} -p /sbin/ldconfig

%changelog
* Sun Nov  1 2020 perry.werneck@gmail.com
- Update to version 5.3+git20201027:
  * Fixing code scanning alerts.
  * Removing unnecessary dependencies.
  * Adding codeql analysis
  * Adjustments for KP_ALTERNATIVE option.
  * Fixing 'kpalternative' option.
  * Adjustments in the file dialog.
  * Adding usefull gtk extension methods from pw3270 application.
  * Enabling copy-as-image action.
  * Adding "copy-as-html" action.
  * Refactoring error popup.
  * Adding signal for customized action fire.
  * Checking for invalid key-file.
  * Adding styles to popup dialog.
  * Adding dynamic font spacing option on settings.
  * Blinking SSL indicator while downloadin CRL.
  * Fixing default keycode for "PF-12".
  * Fixing warnings.
  * Refactoring PFkey engine to allow remapping from accelerator dialog.
  * Working on load/save settings engine.
  * Changing SSL toggle to dropdown to allow more options.
  * Fixing load/save popup return signals.
  * Refactoring popup engine.
  * Delaying "has_timer" signal to avoid thread issues.
  * Adding property with the OIA-Timer state.
  * Enabling keytable search.
  * Allowing image formats on clipboard.
  * Updating filename extension based on file type.
  * Auto selecting format from file extension.
  * Implementing "save as image".
  * Allow to override build date with SOURCE_DATE_EPOCH
* Thu Jun  4 2020 perry.werneck@gmail.com
- Update to version 5.3:
  * Signal tables are now static.
  * Updating README.
  * Fixing build in newest gcc.
  * Changing type of the PACKAGE_RELEASE macro to allow non numeric values.
  * Updating version info.
  * Adding release info when trace window starts.
  * Refactoring accelerator engine.
  * Build instructions for macOS
  * Refactoring keytable management.
  * Sets Courier New as default print font for macOS
  * Change default font for macOS
  * Add support to macosx
  * Disabling "apply" button when host & service name are not set on host properties widget.
  * Show host properties when terminal widget is activated without any host info.
  * Refactoring actions.
  * Adding group on property action (required for screen-model property actions).
  * Fixing security dialog layout on windows.
  * Implementing copy with center button.
  * Adding smart copy options.
  * Fixing toggle actions.
  * Fixing tooltip for screen paste options.
  * Implementing configuration for the "paste screen" option.
  * Implementing clipboard settings dialog.
  * Adding convenience method for comboboxes.
  * Implementing cut&paste settings dialog.
  * Settings dialog should destroy with parent.
  * Moving property based actions to terminal library.
  * Adding signal for OIA clicks.
  * libv3270 now uses his own translation domain.
  * Fixing v3270 state methods.
  * Adding PF/PA Actions.
  * The toggle action now lives in lib3270.
  * Implementing GActions for v3270 terminal.
  * Adding print and save actions in a more standard format.
  * Adding key-file save & load on print operation object.
  * Adding signal for keyfile load on terminal widget.
  * Removing deprecated signals.
  * Implementing accelerator edit widget.
  * CG character 0x20 should be blank.
  * Loading accelerators from keyfile.
  * Isolating CG translation table.
  * Fixing CG char 0x00.
  * Color theme are now standard widget properties.
  * Saving color & host-type properties to settings files.
  * Implementing the "save to keyfile" method.
  * Improving the "can't paste formatted data" popup dialog. It can be disabled now.
  * Fixing "\n" at the end of text copy.
  * Adding default action for the "click" on the OIA's security state icon.
  * Disabling traces when the trace widget is destroyed.
  * The "trace" widget can now be create/destroyed changing a terminal property.
  * "keep-alive" is a network setting, then, it should be in the connection dialog.
  * Refactoring clipboard methods.
  * Fixing charset reset issue.
  * Refactoring configuration dialogs to a more standard and consistent behavior.
  * Adding property for dynamic font space for compatibility with the previous version.
  * Adjustments in the model_number property.
  * Host select widget is now sensible to connection state.
  * Changing the default session name from "application name" to "product name".
  * Fix based on comment from OBS request https://build.opensuse.org/request/show/736258
  * Adjusments base of the comments on OBS Request 735904 (https://build.opensuse.org/request/show/735904)
  * Fixing as requested on review of https://build.opensuse.org/request/show/731972:
  * Trigerring reconfigure event when terminal size changes.
  * Moving charset translation to main library.
  * Getting product name from lib3270 configuration.
  * Refactoring build process.
  * Refactoring "paste from file" method.
  * Refactoring print settings dialog.
  * Adding popup asking for user intervention when the SSL negotiation fails.
  * Removing lib3270 log redirection.
  * Implementing the new smart paste feature.
  * Refactoring clipboard manager.
  * Moving selection management methods to protocol library.
  * Moving terminal definitions to separated include file.
  * Adding signal when session name changes (required for the HLLAPI plugin module).
  * Updating package to follow naming guidelines.
* Mon Oct  7 2019 Ismail Dönmez <idonmez@suse.com>
- Cleanup spec file
- Drop support for <= SLE12-SP2
* Tue Oct  1 2019 Jan Engelhardt <jengelh@inai.de>
- Drop unnecessary build requirements. Own all produced glade
  directories instead.
- Enable parallel build.
- Rectify descriptions.
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use -ffat-lto-objects when building static libraries.
* Fri May 31 2019 perry.werneck@gmail.com
- Update to version 5.2:
  * Fixing package gen.
  * Updating read me.
  * Updating build info.
  * Windows native file dialog is hanging sometimes, replacing it.
  * Updating package info.
  * Adjustments in the V5.1 ft dialog.
  * Working on the new FT dialog.
  * Working on drag & drop for activity list.
* Tue Mar 26 2019 Perry Werneck <perry.werneck@gmail.com>
- Fixing osc source_validator errors.
* Thu Feb 28 2019 Perry Werneck <perry.werneck@gmail.com>
  * Fixing centos build.
  * Adding drag&drop support in the activity list component.
  * Implementing drag&drop on the file settings widget.
  * Updating old (V5.1) transfer dialogs to follow gnome visual layout.
  * Fixing old FT dialog.
  * Updating transfer settings dialog.
  * Refactoring single file transfer dialog.
  * Refactoring simple file transfer dialog.
  * Adding compatibility FT dialog.
  * Fixing RHEL-7 build.
* Tue Dec  4 2018 Perry Werneck <perry.werneck@gmail.com>
  * Refactoring build process.
  * Spliting gtk library from pw3270 main project.
